@@ -734,7 +734,7 @@ main (int argc, char **argv)
 	/* activate or quit */
 	if (quit) {
 		rb_debug ("quitting existing instance");
-		g_action_group_activate_action (G_ACTION_GROUP (app), "Quit", NULL);
+		g_action_group_activate_action (G_ACTION_GROUP (app), "quit", NULL);
 		exit (0);
 	}
 
@@ -822,9 +822,12 @@ main (int argc, char **argv)
 		if (properties != NULL) {
 			GVariant *v = g_hash_table_lookup (properties, "mpris:trackid");
 			if (v != NULL) {
+				gint64 useek;
+
+				useek = seek * 1000000;
 				g_dbus_proxy_call_sync (mpris,
 							"SetPosition",
-							g_variant_new ("(ox)", g_variant_get_string (v, NULL), seek),
+							g_variant_new ("(ox)", g_variant_get_string (v, NULL), useek),
 							G_DBUS_CALL_FLAGS_NONE,
 							-1,
 							NULL,
