@@ -37,7 +37,6 @@
 #include <gtk/gtk.h>
 
 #include "rb-statusbar.h"
-#include "rb-track-transfer-queue.h"
 #include "rb-debug.h"
 
 /**
@@ -77,22 +76,11 @@ static gboolean poll_status (RBStatusbar *status);
 static void rb_statusbar_sync_status (RBStatusbar *status);
 static void rb_statusbar_page_status_changed_cb (RBDisplayPage *page,
 						   RBStatusbar *statusbar);
-static void rb_statusbar_transfer_progress_cb (RBTrackTransferQueue *queue,
-					       int done,
-					       int total,
-					       double fraction,
-					       int time_left,
-					       RBStatusbar *statusbar);
 
 struct RBStatusbarPrivate
 {
         RBDisplayPage *selected_page;
-	RBTrackTransferQueue *transfer_queue;
-
         RhythmDB *db;
-
-        GtkWidget *progress;
-
         guint status_poll_id;
 };
 
@@ -101,7 +89,6 @@ enum
         PROP_0,
         PROP_DB,
         PROP_PAGE,
-	PROP_TRANSFER_QUEUE
 };
 
 G_DEFINE_TYPE (RBStatusbar, rb_statusbar, GTK_TYPE_STATUSBAR)
@@ -141,19 +128,6 @@ rb_statusbar_class_init (RBStatusbarClass *klass)
                                                               "RBDisplayPage object",
                                                               RB_TYPE_DISPLAY_PAGE,
                                                               G_PARAM_READWRITE));
-	/**
-	 * RBStatusbar::transfer-queue:
-	 *
-	 * The #RBTrackTransferQueue instance
-	 */
-	g_object_class_install_property (object_class,
-					 PROP_TRANSFER_QUEUE,
-					 g_param_spec_object ("transfer-queue",
-							      "RBTrackTransferQueue",
-							      "RBTrackTransferQueue instance",
-							      RB_TYPE_TRACK_TRANSFER_QUEUE,
-							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-
 	g_type_class_add_private (klass, sizeof (RBStatusbarPrivate));
 }
 
@@ -163,15 +137,6 @@ rb_statusbar_init (RBStatusbar *statusbar)
 	statusbar->priv = G_TYPE_INSTANCE_GET_PRIVATE (statusbar,
 						       RB_TYPE_STATUSBAR,
 						       RBStatusbarPrivate);
-
-        statusbar->priv->progress = gtk_progress_bar_new ();
-	gtk_widget_set_size_request (statusbar->priv->progress, -1, 10);
-
-        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (statusbar->priv->progress), 1.0);
-        gtk_widget_hide (statusbar->priv->progress);
-
-        gtk_box_pack_start (GTK_BOX (statusbar),
-                            GTK_WIDGET (statusbar->priv->progress), FALSE, TRUE, 0);
 }
 
 static void
@@ -201,11 +166,6 @@ rb_statusbar_dispose (GObject *object)
 		statusbar->priv->selected_page = NULL;
 	}
 
-	if (statusbar->priv->transfer_queue != NULL) {
-		g_object_unref (statusbar->priv->transfer_queue);
-		statusbar->priv->transfer_queue = NULL;
-	}
-
         G_OBJECT_CLASS (rb_statusbar_parent_class)->dispose (object);
 }
 
@@ -260,14 +220,6 @@ rb_statusbar_set_property (GObject *object,
 		rb_statusbar_sync_status (statusbar);
 
                 break;
-	case PROP_TRANSFER_QUEUE:
-		statusbar->priv->transfer_queue = g_value_dup_object (value);
-		g_signal_connect_object (G_OBJECT (statusbar->priv->transfer_queue),
-					 "transfer-progress",
-					 G_CALLBACK (rb_statusbar_transfer_progress_cb),
-					 statusbar,
-					 0);
-		break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
                 break;
@@ -290,9 +242,6 @@ rb_statusbar_get_property (GObject *object,
         case PROP_PAGE:
                 g_value_set_object (value, statusbar->priv->selected_page);
                 break;
-        case PROP_TRANSFER_QUEUE:
-                g_value_set_object (value, statusbar->priv->transfer_queue);
-                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
                 break;
@@ -331,28 +280,9 @@ poll_status (RBStatusbar *status)
 static void
 rb_statusbar_sync_status (RBStatusbar *status)
 {
-        gboolean changed = FALSE;
         char *status_text = NULL;
 	char *progress_text = NULL;
 	float progress = 999;
-	int time_left = 0;
-
-        /*
-         * Behaviour of status bar:
-	 * - use page's status text
-	 * - use page's progress value and text, unless transfer queue provides something
-	 * - if no page progress value or transfer progress value and library is busy,
-	 *    pulse the progress bar
-         */
-        
-	/* library busy? */
-        if (rhythmdb_is_busy (status->priv->db)) {
-		progress = -1.0f;
-
-		/* see if it wants to provide more details */
-		rhythmdb_get_progress_info (status->priv->db, &progress_text, &progress);
-		changed = TRUE;
-        }
 
 	/* get page details */
         if (status->priv->selected_page) {
@@ -361,59 +291,29 @@ rb_statusbar_sync_status (RBStatusbar *status)
 			status_text ? status_text : "", progress_text ? progress_text : "", progress);
 	}
 
-	/* get transfer details */
-	rb_track_transfer_queue_get_status (status->priv->transfer_queue,
-					    &status_text,
-					    &progress_text,
-					    &progress,
-					    &time_left);
-
         /* set up the status text */
         if (status_text) {
                 gtk_statusbar_pop (GTK_STATUSBAR (status), 0);
                 gtk_statusbar_push (GTK_STATUSBAR (status), 0, status_text);
-		g_free (status_text);
         }
 
-        /* set up the progress bar */
-	if (progress > (1.0f - EPSILON)) {
-		gtk_widget_hide (status->priv->progress);
-	} else {
-                gtk_widget_show (status->priv->progress);
-
-                if (progress < EPSILON) {
-			gtk_progress_bar_pulse (GTK_PROGRESS_BAR (status->priv->progress));
-                        changed = TRUE;
-                } else {
-                        gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (status->priv->progress),
-                                                       progress);
-                }
-		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (status->priv->progress),
-					   progress_text);
-	}
-
 	g_free (progress_text);
-
-        if (status->priv->status_poll_id == 0 && changed)
-                status->priv->status_poll_id = g_timeout_add (250, (GSourceFunc) poll_status, status);
+	g_free (status_text);
 }
 
 /**
  * rb_statusbar_new:
  * @db: the #RhythmDB instance
- * @transfer_queue: the #RBTrackTransferQueue
  *
  * Creates the status bar widget.
  *
  * Return value: the status bar widget
  */
 RBStatusbar *
-rb_statusbar_new (RhythmDB *db,
-		  RBTrackTransferQueue *queue)
+rb_statusbar_new (RhythmDB *db)
 {
         RBStatusbar *statusbar = g_object_new (RB_TYPE_STATUSBAR,
                                                "db", db,
-					       "transfer-queue", queue,
                                                NULL);
 
         g_return_val_if_fail (statusbar->priv != NULL, NULL);
@@ -422,28 +322,10 @@ rb_statusbar_new (RhythmDB *db,
 }
 
 static void
-add_status_poll (RBStatusbar *statusbar)
+rb_statusbar_page_status_changed_cb (RBDisplayPage *page, RBStatusbar *statusbar)
 {
+	rb_debug ("source status changed");
         if (statusbar->priv->status_poll_id == 0)
                 statusbar->priv->status_poll_id =
                         g_idle_add ((GSourceFunc) poll_status, statusbar);
 }
-
-static void
-rb_statusbar_page_status_changed_cb (RBDisplayPage *page, RBStatusbar *statusbar)
-{
-	rb_debug ("source status changed");
-	add_status_poll (statusbar);
-}
-
-static void
-rb_statusbar_transfer_progress_cb (RBTrackTransferQueue *queue,
-				   int done,
-				   int total,
-				   double progress,
-				   int time_left,
-				   RBStatusbar *statusbar)
-{
-	rb_debug ("transfer progress changed");
-	add_status_poll (statusbar);
-}
