@@ -73,6 +73,8 @@
 #include "rb-display-page-menu.h"
 #include "rb-display-page-group.h"
 #include "rb-static-playlist-source.h"
+#include "rb-task-list.h"
+#include "rhythmdb-import-job.h"
 
 #define SOURCE_PAGE		0
 #define IMPORT_DIALOG_PAGE	1
@@ -85,7 +87,6 @@ static void rb_library_source_finalize (GObject *object);
 
 static GtkWidget *impl_get_config_widget (RBDisplayPage *source, RBShellPreferences *prefs);
 static gboolean impl_receive_drag (RBDisplayPage *source, GtkSelectionData *data);
-static void impl_get_status (RBDisplayPage *source, char **text, char **progress_text, float *progress);
 
 static gboolean impl_can_paste (RBSource *asource);
 static RBTrackTransferBatch *impl_paste (RBSource *source, GList *entries);
@@ -124,16 +125,16 @@ typedef struct {
 	char *path;
 } LibraryPathElement;
 
-const LibraryPathElement library_layout_paths[] = {
+static const LibraryPathElement library_layout_paths[] = {
 	{N_("Artist/Artist - Album"), "%aa/%aa - %at"},
 	{N_("Artist/Album"), "%aa/%at"},
 	{N_("Artist - Album"), "%aa - %at"},
 	{N_("Album"), "%at"},
 	{N_("Artist"), "%aa"},
 };
-const int num_library_layout_paths = G_N_ELEMENTS (library_layout_paths);
+static const int num_library_layout_paths = G_N_ELEMENTS (library_layout_paths);
 
-const LibraryPathElement library_layout_filenames[] = {
+static const LibraryPathElement library_layout_filenames[] = {
 	{N_("Number - Title"), "%tN - %tt"},
 	{N_("Artist - Title"), "%ta - %tt"},
 	{N_("Artist - Number - Title"), "%ta - %tN - %tt"},
@@ -141,9 +142,22 @@ const LibraryPathElement library_layout_filenames[] = {
 	{N_("Title"), "%tt"},
 	{N_("Number. Artist - Title"), "%tN. %ta - %tt"},
 };
-const int num_library_layout_filenames = G_N_ELEMENTS (library_layout_filenames);
+static const int num_library_layout_filenames = G_N_ELEMENTS (library_layout_filenames);
+
+#define CUSTOM_SETTINGS_PREFIX "rhythmbox-custom-settings"
+#define CBR_SETTINGS_PRESET CUSTOM_SETTINGS_PREFIX "-cbr"
+/* this preset name was used in releases where we only had VBR custom settings */
+#define VBR_SETTINGS_PRESET CUSTOM_SETTINGS_PREFIX
+
+static struct {
+	const char *style;
+	const char *label;
+	const char *preset;
+} library_encoding_styles[] = {
+	{ "cbr", N_("Constant bit rate"), CBR_SETTINGS_PRESET },
+	{ "vbr", N_("Variable bit rate"), VBR_SETTINGS_PRESET },
+};
 
-#define CUSTOM_SETTINGS_PRESET	"rhythmbox-custom-settings"
 
 struct RBLibrarySourcePrivate
 {
@@ -174,8 +188,8 @@ struct RBLibrarySourcePrivate
 	GList *import_jobs;
 	guint start_import_job_id;
 	gulong profile_changed_id;
-	gboolean custom_settings_exists;
 	gboolean profile_init;
+	char *preset_name;
 	gboolean do_initial_import;
 
 	GSettings *settings;
@@ -200,7 +214,6 @@ rb_library_source_class_init (RBLibrarySourceClass *klass)
 
 	page_class->get_config_widget = impl_get_config_widget;
 	page_class->receive_drag = impl_receive_drag;
-	page_class->get_status = impl_get_status;
 
 	source_class->impl_can_copy = (RBSourceFeatureFunc) rb_true_function;
 	source_class->impl_can_paste = (RBSourceFeatureFunc) impl_can_paste;
@@ -421,17 +434,9 @@ RBSource *
 rb_library_source_new (RBShell *shell)
 {
 	RBSource *source;
-	GdkPixbuf *icon;
 	GSettings *settings;
 	GtkBuilder *builder;
 	GMenu *toolbar;
-	gint size;
-
-	gtk_icon_size_lookup (RB_SOURCE_ICON_SIZE, &size, NULL);
-	icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-					 "audio-x-generic",
-					 size,
-					 0, NULL);
 	settings = g_settings_new ("org.gnome.rhythmbox.library");
 
 	builder = rb_builder_load ("library-toolbar.ui", NULL);
@@ -442,14 +447,11 @@ rb_library_source_new (RBShell *shell)
 					  "name", _("Music"),
 					  "entry-type", RHYTHMDB_ENTRY_TYPE_SONG,
 					  "shell", shell,
-					  "pixbuf", icon,
 					  "populate", FALSE,		/* wait until the database is loaded */
 					  "toolbar-menu", toolbar,
 					  "settings", g_settings_get_child (settings, "source"),
 					  NULL));
-	if (icon != NULL) {
-		g_object_unref (icon);
-	}
+	rb_display_page_set_icon_name (RB_DISPLAY_PAGE (source), "folder-music-symbolic");
 	g_object_unref (settings);
 	g_object_unref (builder);
 
@@ -587,7 +589,9 @@ update_layout_filename (RBLibrarySource *source)
 	}
 	g_free (value);
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (source->priv->layout_filename_menu), active);
+	if (source->priv->layout_filename_menu != NULL) {
+		gtk_combo_box_set_active (GTK_COMBO_BOX (source->priv->layout_filename_menu), active);
+	}
 
 	update_layout_example_label (source);
 }
@@ -615,9 +619,78 @@ profile_changed_cb (RBObjectPropertyEditor *editor, RBLibrarySource *source)
 	if (source->priv->profile_init)
 		return;
 
-	if (source->priv->encoder_element)
+	if (source->priv->encoder_element) {
+		rb_debug ("updating preset %s", source->priv->preset_name);
 		gst_preset_save_preset (GST_PRESET (source->priv->encoder_element),
-						    CUSTOM_SETTINGS_PRESET);
+						    source->priv->preset_name);
+	}
+}
+
+static void
+update_property_editor_for_preset (RBLibrarySource *source, const char *media_type, const char *preset)
+{
+	int i;
+	int style;
+
+	/* figure out if this is a user-settings preset name */
+	style = -1;
+	for (i = 0; i < G_N_ELEMENTS (library_encoding_styles); i++) {
+		if (g_strcmp0 (preset, library_encoding_styles[i].preset) == 0) {
+			style = i;
+			break;
+		}
+	}
+
+	/* remove old property editor, if there is one */
+	if (source->priv->encoder_property_editor != NULL) {
+		g_signal_handler_disconnect (source->priv->encoder_property_editor,
+					     source->priv->profile_changed_id);
+
+		gtk_container_remove (GTK_CONTAINER (source->priv->encoder_property_holder),
+				      source->priv->encoder_property_editor);
+		source->priv->profile_changed_id = 0;
+		source->priv->encoder_property_editor = NULL;
+		g_free (source->priv->preset_name);
+		source->priv->preset_name = NULL;
+	}
+
+	/* create new property editor, if required */
+	if (style != -1 && source->priv->encoder_element) {
+		GstEncodingProfile *profile;
+		char **profile_settings;
+
+		/* make sure the preset exists so encoder batches can use it */
+		if (gst_preset_load_preset (GST_PRESET (source->priv->encoder_element), preset) == FALSE) {
+			if (rb_gst_encoder_set_encoding_style (source->priv->encoder_element,
+							       library_encoding_styles[style].style)) {
+				gst_preset_save_preset (GST_PRESET (source->priv->encoder_element),
+							preset);
+			}
+		}
+
+		profile = rb_gst_get_encoding_profile (media_type);
+		profile_settings =
+			rb_gst_encoding_profile_get_settings (profile,
+							      library_encoding_styles[style].style);
+		source->priv->encoder_property_editor =
+			rb_object_property_editor_new (G_OBJECT (source->priv->encoder_element),
+						       profile_settings);
+		g_strfreev (profile_settings);
+		gst_encoding_profile_unref (profile);
+
+		source->priv->profile_changed_id =
+			g_signal_connect (source->priv->encoder_property_editor,
+					  "changed",
+					  G_CALLBACK (profile_changed_cb),
+					  source);
+
+		gtk_grid_attach (GTK_GRID (source->priv->encoder_property_holder),
+				 source->priv->encoder_property_editor,
+				 0, 0, 1, 1);
+		gtk_widget_show_all (source->priv->encoder_property_editor);
+
+		source->priv->preset_name = g_strdup (preset);
+	}
 }
 
 static void
@@ -628,19 +701,12 @@ update_presets (RBLibrarySource *source, const char *media_type)
 	GstEncodingProfile *profile;
 	char **profile_settings;
 	char **profile_presets;
+	int i;
 
 	source->priv->profile_init = TRUE;
 
 	gtk_list_store_clear (GTK_LIST_STORE (source->priv->preset_model));
 
-	if (source->priv->encoder_property_editor != NULL) {
-		g_signal_handler_disconnect (source->priv->encoder_property_editor,
-					     source->priv->profile_changed_id);
-		gtk_container_remove (GTK_CONTAINER (source->priv->encoder_property_holder),
-				      source->priv->encoder_property_editor);
-		source->priv->profile_changed_id = 0;
-		source->priv->encoder_property_editor = NULL;
-	}
 	if (source->priv->encoder_element != NULL) {
 		gst_object_unref (source->priv->encoder_element);
 		source->priv->encoder_element = NULL;
@@ -670,40 +736,19 @@ update_presets (RBLibrarySource *source, const char *media_type)
 		source->priv->profile_init = FALSE;
 		return;
 	}
+	source->priv->encoder_element = rb_gst_encoding_profile_get_encoder (profile);
 
-	profile_settings = rb_gst_encoding_profile_get_settings (profile);
-	if (profile_settings != NULL) {
+	for (i = 0; i < G_N_ELEMENTS (library_encoding_styles); i++) {
+		profile_settings = rb_gst_encoding_profile_get_settings (profile, library_encoding_styles[i].style);
+		if (profile_settings == NULL)
+			continue;
 
-		rb_debug ("profile has custom settings");
+		rb_debug ("profile has custom settings for style %s", library_encoding_styles[i].style);
 		insert_preset (source,
-			       _("Custom settings"),
-			       CUSTOM_SETTINGS_PRESET,
-			       g_strcmp0 (active_preset, CUSTOM_SETTINGS_PRESET) == 0);
+			       gettext (library_encoding_styles[i].label),
+			       library_encoding_styles[i].preset,
+			       g_strcmp0 (active_preset, library_encoding_styles[i].preset) == 0);
 		gtk_widget_set_sensitive (source->priv->preset_menu, TRUE);
-
-		source->priv->encoder_element = rb_gst_encoding_profile_get_encoder (profile);
-		source->priv->custom_settings_exists =
-			gst_preset_load_preset (GST_PRESET (source->priv->encoder_element),
-						CUSTOM_SETTINGS_PRESET);
-
-		source->priv->encoder_property_editor =
-			rb_object_property_editor_new (G_OBJECT (source->priv->encoder_element),
-						       profile_settings);
-		source->priv->profile_changed_id =
-			g_signal_connect (source->priv->encoder_property_editor,
-					  "changed",
-					  G_CALLBACK (profile_changed_cb),
-					  source);
-
-		gtk_grid_attach (GTK_GRID (source->priv->encoder_property_holder),
-				 source->priv->encoder_property_editor,
-				 0, 0, 1, 1);
-		gtk_widget_show_all (source->priv->encoder_property_editor);
-		gtk_widget_set_no_show_all (source->priv->encoder_property_editor, TRUE);
-		if (g_strcmp0 (active_preset, CUSTOM_SETTINGS_PRESET) != 0) {
-			gtk_widget_hide (source->priv->encoder_property_editor);
-		}
-		g_strfreev (profile_settings);
 	}
 
 	/* get list of actual presets for the media type */
@@ -711,7 +756,7 @@ update_presets (RBLibrarySource *source, const char *media_type)
 	if (profile_presets) {
 		int i;
 		for (i = 0; profile_presets[i] != NULL; i++) {
-			if (g_strcmp0 (profile_presets[i], CUSTOM_SETTINGS_PRESET) == 0)
+			if (g_str_has_prefix (profile_presets[i], CUSTOM_SETTINGS_PREFIX))
 				continue;
 
 			rb_debug ("profile has preset %s", profile_presets[i]);
@@ -724,6 +769,8 @@ update_presets (RBLibrarySource *source, const char *media_type)
 		g_strfreev (profile_presets);
 	}
 
+	update_property_editor_for_preset (source, media_type, active_preset);
+
 	gst_encoding_profile_unref (profile);
 	source->priv->profile_init = FALSE;
 }
@@ -735,6 +782,9 @@ update_preferred_media_type (RBLibrarySource *source)
 	gboolean done;
 	char *str;
 
+	if (source->priv->profile_model == NULL)
+		return;
+
 	done = FALSE;
 	str = g_settings_get_string (source->priv->encoding_settings, "media-type");
 	if (gtk_tree_model_get_iter_first (source->priv->profile_model, &iter)) {
@@ -826,7 +876,7 @@ impl_get_config_widget (RBDisplayPage *asource, RBShellPreferences *prefs)
 			  "clicked",
 			  G_CALLBACK (rb_library_source_location_button_clicked_cb),
 			  asource);
-	g_signal_connect (G_OBJECT (source->priv->library_location_entry),
+	g_signal_connect (source->priv->library_location_entry,
 			  "focus-out-event",
 			  G_CALLBACK (rb_library_source_library_location_cb),
 			  asource);
@@ -843,7 +893,7 @@ impl_get_config_widget (RBDisplayPage *asource, RBShellPreferences *prefs)
 	source->priv->layout_path_menu = gtk_combo_box_text_new ();
 	gtk_box_pack_start (GTK_BOX (tmp), source->priv->layout_path_menu, TRUE, TRUE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), source->priv->layout_path_menu);
-	g_signal_connect (G_OBJECT (source->priv->layout_path_menu),
+	g_signal_connect (source->priv->layout_path_menu,
 			  "changed",
 			  G_CALLBACK (rb_library_source_path_changed_cb),
 			  asource);
@@ -857,7 +907,7 @@ impl_get_config_widget (RBDisplayPage *asource, RBShellPreferences *prefs)
 	source->priv->layout_filename_menu = gtk_combo_box_text_new ();
 	gtk_box_pack_start (GTK_BOX (tmp), source->priv->layout_filename_menu, TRUE, TRUE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), source->priv->layout_filename_menu);
-	g_signal_connect (G_OBJECT (source->priv->layout_filename_menu),
+	g_signal_connect (source->priv->layout_filename_menu,
 			  "changed",
 			  G_CALLBACK (rb_library_source_filename_changed_cb),
 			  asource);
@@ -895,7 +945,7 @@ impl_get_config_widget (RBDisplayPage *asource, RBShellPreferences *prefs)
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (source->priv->preferred_format_menu), renderer, TRUE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (source->priv->preferred_format_menu), renderer, "text", 1, NULL);
 
-	g_signal_connect (G_OBJECT (source->priv->preferred_format_menu),
+	g_signal_connect (source->priv->preferred_format_menu,
 			  "changed",
 			  G_CALLBACK (rb_library_source_format_changed_cb),
 			  asource);
@@ -906,7 +956,7 @@ impl_get_config_widget (RBDisplayPage *asource, RBShellPreferences *prefs)
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (source->priv->preset_menu), renderer, TRUE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (source->priv->preset_menu), renderer, "text", 0, NULL);
 
-	g_signal_connect (G_OBJECT (source->priv->preset_menu),
+	g_signal_connect (source->priv->preset_menu,
 			  "changed",
 			  G_CALLBACK (rb_library_source_preset_changed_cb),
 			  asource);
@@ -916,7 +966,7 @@ impl_get_config_widget (RBDisplayPage *asource, RBShellPreferences *prefs)
 
 	source->priv->install_plugins_button = GTK_WIDGET (gtk_builder_get_object (builder, "install_plugins_button"));
 	gtk_widget_set_no_show_all (source->priv->install_plugins_button, TRUE);
-	g_signal_connect (G_OBJECT (source->priv->install_plugins_button), "clicked", G_CALLBACK (rb_library_source_install_plugins_cb), source);
+	g_signal_connect (source->priv->install_plugins_button, "clicked", G_CALLBACK (rb_library_source_install_plugins_cb), source);
 
 	source->priv->encoder_property_holder = GTK_WIDGET (gtk_builder_get_object (builder, "encoder_property_holder"));
 
@@ -1100,23 +1150,7 @@ rb_library_source_preset_changed_cb (GtkWidget *widget, RBLibrarySource *source)
 		rb_debug ("no preset selected for media type %s?", media_type);
 	}
 
-	/* update custom settings widgets */
-	if (g_strcmp0 (preset, CUSTOM_SETTINGS_PRESET) == 0) {
-		/* make sure the preset exists so encoder batches can use it */
-		if (source->priv->custom_settings_exists == FALSE) {
-			gst_preset_save_preset (GST_PRESET (source->priv->encoder_element),
-						CUSTOM_SETTINGS_PRESET);
-		}
-
-		if (source->priv->encoder_property_editor != NULL) {
-			gtk_widget_show (source->priv->encoder_property_editor);
-		}
-	} else {
-
-		if (source->priv->encoder_property_editor != NULL) {
-			gtk_widget_hide (source->priv->encoder_property_editor);
-		}
-	}
+	update_property_editor_for_preset (source, media_type, preset);
 
 	/* store selected preset */
 	settings = g_settings_get_value (source->priv->encoding_settings, "media-type-presets");
@@ -1437,6 +1471,10 @@ update_layout_example_label (RBLibrarySource *source)
 	RhythmDBEntryType *entry_type;
 	RhythmDBEntry *sample_entry;
 
+	if (source->priv->layout_example_label == NULL) {
+		return;
+	}
+
 	media_type = g_settings_get_string (source->priv->encoding_settings, "media-type");
 
 	file_pattern = g_settings_get_string (source->priv->settings, "layout-filename");
@@ -1679,7 +1717,6 @@ impl_paste (RBSource *asource, GList *entries)
 		      "entry-type", &source_entry_type,
 		      NULL);
 	g_object_get (shell, "track-transfer-queue", &xferq, NULL);
-	g_object_unref (shell);
 
 	target = gst_encoding_target_new ("rhythmbox-library", "device", "", NULL);
 
@@ -1730,13 +1767,21 @@ impl_paste (RBSource *asource, GList *entries)
 	g_object_unref (source_entry_type);
 
 	if (start_batch) {
+		RBTaskList *tasklist;
+
+		g_object_set (batch, "task-label", _("Copying tracks to the library"), NULL);
 		rb_track_transfer_queue_start_batch (xferq, batch);
+
+		g_object_get (shell, "task-list", &tasklist, NULL);
+		rb_task_list_add_task (tasklist, RB_TASK_PROGRESS (batch));
+		g_object_unref (tasklist);
 	} else {
 		g_object_unref (batch);
 		batch = NULL;
 	}
 
 	g_object_unref (xferq);
+	g_object_unref (shell);
 	return batch;
 }
 
@@ -1753,15 +1798,6 @@ impl_want_uri (RBSource *source, const char *uri)
 	return 0;
 }
 
-static void
-import_job_status_changed_cb (RhythmDBImportJob *job, int total, int imported, RBLibrarySource *source)
-{
-	RhythmDBImportJob *head = RHYTHMDB_IMPORT_JOB (source->priv->import_jobs->data);
-	if (job == head) {		/* it was inevitable */
-		rb_display_page_notify_status_changed (RB_DISPLAY_PAGE (source));
-	}
-}
-
 static void
 import_job_complete_cb (RhythmDBImportJob *job, int total, RBLibrarySource *source)
 {
@@ -1777,6 +1813,9 @@ static gboolean
 start_import_job (RBLibrarySource *source)
 {
 	RhythmDBImportJob *job;
+	RBTaskList *tasklist;
+	RBShell *shell;
+
 	source->priv->start_import_job_id = 0;
 
 	rb_debug ("starting import job");
@@ -1784,6 +1823,12 @@ start_import_job (RBLibrarySource *source)
 
 	rhythmdb_import_job_start (job);
 
+	g_object_get (source, "shell", &shell, NULL);
+	g_object_get (shell, "task-list", &tasklist, NULL);
+	rb_task_list_add_task (tasklist, RB_TASK_PROGRESS (job));
+	g_object_unref (tasklist);
+	g_object_unref (shell);
+
 	return FALSE;
 }
 
@@ -1798,11 +1843,8 @@ maybe_create_import_job (RBLibrarySource *source)
 					       RHYTHMDB_ENTRY_TYPE_SONG,
 					       RHYTHMDB_ENTRY_TYPE_IGNORE,
 					       RHYTHMDB_ENTRY_TYPE_IMPORT_ERROR);
+		g_object_set (job, "task-label", _("Adding tracks to the library"), NULL);
 
-		g_signal_connect_object (job,
-					 "status-changed",
-					 G_CALLBACK (import_job_status_changed_cb),
-					 source, 0);
 		g_signal_connect_object (job,
 					 "complete",
 					 G_CALLBACK (import_job_complete_cb),
@@ -1884,7 +1926,7 @@ rb_library_source_add_child_source (const char *path, RBLibrarySource *library_s
 	GPtrArray *query;
 	RBShell *shell;
 	char *name;
-	GdkPixbuf *icon;
+	GIcon *icon;
 	RhythmDBEntryType *entry_type;
 	char *sort_column;
 	int sort_order;
@@ -1895,7 +1937,7 @@ rb_library_source_add_child_source (const char *path, RBLibrarySource *library_s
 		      "shell", &shell,
 		      "entry-type", &entry_type,
 		      "playlist-menu", &playlist_menu,
-		      "pixbuf", &icon,
+		      "icon", &icon,
 		      NULL);
 
 	file = g_file_new_for_uri (path);
@@ -1917,7 +1959,7 @@ rb_library_source_add_child_source (const char *path, RBLibrarySource *library_s
 	g_free (sort_column);
 
 	g_object_set (source,
-		      "pixbuf", icon,
+		      "icon", icon,
 		      "playlist-menu", playlist_menu,
 		      NULL);
 
@@ -1954,21 +1996,6 @@ rb_library_source_sync_child_sources (RBLibrarySource *source)
 	g_strfreev (locations);
 }
 
-static void
-impl_get_status (RBDisplayPage *source, char **text, char **progress_text, float *progress)
-{
-	RB_DISPLAY_PAGE_CLASS (rb_library_source_parent_class)->get_status (source, text, progress_text, progress);
-	RBLibrarySource *lsource = RB_LIBRARY_SOURCE (source);
-
-	if (lsource->priv->import_jobs != NULL) {
-		RhythmDBImportJob *job = RHYTHMDB_IMPORT_JOB (lsource->priv->import_jobs->data);
-		_rb_source_set_import_status (RB_SOURCE (source), job, progress_text, progress);
-	} else if (gtk_notebook_get_current_page (GTK_NOTEBOOK (lsource->priv->notebook)) == IMPORT_DIALOG_PAGE) {
-		g_free (*text);
-		g_object_get (lsource->priv->import_dialog, "status", text, NULL);
-	}
-}
-
 static void
 import_dialog_closed_cb (RBImportDialog *dialog, RBLibrarySource *source)
 {
