@@ -37,6 +37,9 @@
 #include <gtk/gtk.h>
 #include <totem-pl-parser.h>
 
+#define G_SETTINGS_ENABLE_BACKEND
+#include <gio/gsettingsbackend.h>
+
 #include "rb-entry-view.h"
 #include "rb-search-entry.h"
 #include "rb-file-helpers.h"
@@ -151,6 +154,8 @@ enum
 
 static const GtkTargetEntry target_uri [] = { { "text/uri-list", 0, 0 } };
 
+static GSettingsBackend *playlist_settings_backend = NULL;
+
 G_DEFINE_ABSTRACT_TYPE (RBPlaylistSource, rb_playlist_source, RB_TYPE_SOURCE);
 
 static void
@@ -228,6 +233,10 @@ static void
 rb_playlist_source_init (RBPlaylistSource *source)
 {
 	source->priv = RB_PLAYLIST_SOURCE_GET_PRIVATE (source);
+	
+	if (playlist_settings_backend == NULL) {
+		playlist_settings_backend = g_memory_settings_backend_new ();
+	}
 }
 
 static void
@@ -253,6 +262,12 @@ rb_playlist_source_set_db (RBPlaylistSource *source,
 
 }
 
+static void
+playlist_settings_changed_cb (GSettings *settings, char *key, RBPlaylistSource *source)
+{
+	rb_playlist_source_mark_dirty (source);
+}
+
 static void
 rb_playlist_source_constructed (GObject *object)
 {
@@ -262,6 +277,7 @@ rb_playlist_source_constructed (GObject *object)
 	RhythmDB *db;
 	RhythmDBQueryModel *query_model;
 	GtkBuilder *builder;
+	GSettings *settings;
 
 	RB_CHAIN_GOBJECT_METHOD (rb_playlist_source_parent_class, constructed, object);
 	source = RB_PLAYLIST_SOURCE (object);
@@ -276,6 +292,27 @@ rb_playlist_source_constructed (GObject *object)
 
 	g_object_unref (shell);
 
+	/* store playlist settings using the memory backend
+	 * this means the settings path doesn't have to be consistent,
+	 * it just has to be unique, so the address of the source object works.
+	 * for local playlists, we write the settings into the playlist file on disk
+	 * to make them persistent.
+	 */
+	g_object_get (source, "settings", &settings, NULL);
+	if (settings == NULL) {
+		char *path;
+		path = g_strdup_printf ("/org/gnome/rhythmbox/playlist/%p/", source);
+		settings = g_settings_new_with_backend_and_path ("org.gnome.rhythmbox.source",
+								 playlist_settings_backend,
+								 path);
+		g_free (path);
+
+		g_object_set (source, "settings", settings, NULL);
+	}
+
+	g_signal_connect (settings, "changed", G_CALLBACK (playlist_settings_changed_cb), source);
+	g_object_unref (settings);
+
 	builder = rb_builder_load ("playlist-popup.ui", NULL);
 	source->priv->popup = G_MENU (gtk_builder_get_object (builder, "playlist-popup"));
 	rb_application_link_shared_menus (RB_APPLICATION (g_application_get_default ()), source->priv->popup);
@@ -332,6 +369,7 @@ rb_playlist_source_constructed (GObject *object)
 	rb_entry_view_append_column (source->priv->songs, RB_ENTRY_VIEW_COL_TITLE, TRUE);
 	rb_entry_view_append_column (source->priv->songs, RB_ENTRY_VIEW_COL_GENRE, FALSE);
 	rb_entry_view_append_column (source->priv->songs, RB_ENTRY_VIEW_COL_ARTIST, FALSE);
+	rb_entry_view_append_column (source->priv->songs, RB_ENTRY_VIEW_COL_COMPOSER, FALSE);
 	rb_entry_view_append_column (source->priv->songs, RB_ENTRY_VIEW_COL_ALBUM, FALSE);
 	rb_entry_view_append_column (source->priv->songs, RB_ENTRY_VIEW_COL_YEAR, FALSE);
 	rb_entry_view_append_column (source->priv->songs, RB_ENTRY_VIEW_COL_DURATION, FALSE);
@@ -752,6 +790,45 @@ get_playlist_name_from_xml (xmlNodePtr node)
 	return name;
 }
 
+static void
+apply_source_settings (RBPlaylistSource *source, xmlNodePtr node)
+{
+	GSettings *settings;
+	xmlChar *value;
+
+	g_object_get (source, "settings", &settings, NULL);
+	if (settings == NULL)
+		return;
+
+	value = xmlGetProp (node, RB_PLAYLIST_SHOW_BROWSER);
+	if (value != NULL) {
+		g_settings_set_boolean (settings,
+					"show-browser",
+					(g_strcmp0 ((char *)value, "true") == 0));
+		xmlFree (value);
+	}
+	
+	value = xmlGetProp (node, RB_PLAYLIST_BROWSER_POSITION);
+	if (value != NULL) {
+		long position;
+		char *end;
+
+		position = strtol ((char *)value, &end, 10);
+		if (end != (char *)value) {
+			g_settings_set_int (settings, "paned-position", position);
+		}
+		xmlFree (value);
+	}
+
+	value = xmlGetProp (node, RB_PLAYLIST_SEARCH_TYPE);
+	if (value != NULL) {
+		g_settings_set_string (settings, "search-type", (char *)value);
+		xmlFree (value);
+	}
+
+	g_object_unref (settings);
+}
+
 /**
  * rb_playlist_source_new_from_xml:
  * @shell: the #RBShell instance
@@ -781,26 +858,26 @@ rb_playlist_source_new_from_xml	(RBShell *shell,
 	tmp = xmlGetProp (node, RB_PLAYLIST_TYPE);
 
 	if (!xmlStrcmp (tmp, RB_PLAYLIST_AUTOMATIC))
-		source = rb_auto_playlist_source_new_from_xml (shell, node);
+		source = rb_auto_playlist_source_new_from_xml (shell, (const char *)name, node);
 	else if (!xmlStrcmp (tmp, RB_PLAYLIST_STATIC))
-		source = rb_static_playlist_source_new_from_xml (shell, node);
+		source = rb_static_playlist_source_new_from_xml (shell, (const char *)name, node);
 	else if (!xmlStrcmp (tmp, RB_PLAYLIST_QUEUE)) {
 		RBStaticPlaylistSource *queue;
 
 		g_object_get (shell, "queue-source", &queue, NULL);
 		rb_static_playlist_source_load_from_xml (queue, node);
+		apply_source_settings (RB_PLAYLIST_SOURCE (queue), node);
 		g_object_unref (queue);
 	} else {
 		g_warning ("attempting to load playlist '%s' of unknown type '%s'", name, tmp);
 	}
 
-	if (source != NULL) {
-		g_object_set (G_OBJECT (source), "name", name, NULL);
-	}
-
 	xmlFree (name);
 	xmlFree (tmp);
 
+	if (source != NULL) {
+		apply_source_settings (RB_PLAYLIST_SOURCE (source), node);
+	}
 	return source;
 }
 
@@ -818,6 +895,7 @@ rb_playlist_source_save_to_xml (RBPlaylistSource *source,
 {
 	xmlNodePtr node;
 	xmlChar *name;
+	GSettings *settings;
 	RBPlaylistSourceClass *klass = RB_PLAYLIST_SOURCE_GET_CLASS (source);
 
 	g_return_if_fail (RB_IS_PLAYLIST_SOURCE (source));
@@ -827,6 +905,21 @@ rb_playlist_source_save_to_xml (RBPlaylistSource *source,
 	xmlSetProp (node, RB_PLAYLIST_NAME, name);
 	g_free (name);
 
+	g_object_get (source, "settings", &settings, NULL);
+	if (settings) {
+		char buf[99];
+		xmlSetProp (node,
+			    RB_PLAYLIST_SHOW_BROWSER,
+			    (xmlChar *)(g_settings_get_boolean (settings, "show-browser") ? "true" : "false"));
+
+		sprintf (buf, "%d", g_settings_get_int (settings, "paned-position"));
+		xmlSetProp (node, RB_PLAYLIST_BROWSER_POSITION, (xmlChar *)buf);
+
+		xmlSetProp (node, RB_PLAYLIST_SEARCH_TYPE, (xmlChar *)g_settings_get_string (settings, "search-type"));
+		g_object_unref (settings);
+	}
+
+
 	klass->impl_save_contents_to_xml (source, node);
 
 	source->priv->dirty = FALSE;
